<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang[' and %d virtual'] = " and %d virtual";
$lang[' and %d virtual'] = " and %d virtual";
$lang['%d album including'] = "%d album including";
$lang['%d album moved'] = "%d album moved";
$lang['%d albums including'] = "%d albums including";
$lang['%d albums moved'] = "%d albums moved";
$lang['%d anomalies have been detected corrected.'] = "%d anomalies have been detected and corrected.";
$lang['%d anomalies have been detected.'] = "%d anomalies have been detected.";
$lang['%d anomalies have been ignored.'] = "%d anomalies have been ignored.";
$lang['%d anomalies have not been corrected.'] = "%d anomalies have not been corrected.";
$lang['%d anomaly has been corrected.'] = "%d anomaly has been corrected.";
$lang['%d anomaly has been detected.'] = "%d anomaly has been detected.";
$lang['%d anomaly has been ignored.'] = "%d anomaly has been ignored.";
$lang['%d anomaly has not been corrected.'] = "%d anomaly has not been corrected.";
$lang['%d association'] = "%d association";
$lang['%d associations'] = "%d associations";
$lang['%d group'] = "%d group";
$lang['%d groups'] = "%d groups";
$lang['%d guest'] = "%d guest";
$lang['%d guests'] = "%d guests";
$lang['%d line filtered'] = "%d line filtered";
$lang['%d lines filtered'] = "%d lines filtered";
$lang['%d mail was not sent.'] = "%d mail has not been sent.";
$lang['%d mail was sent.'] = "%d mail has been sent.";
$lang['%d mails were not sent.'] = "%d mails have not been sent.";
$lang['%d mails were sent.'] = "%d mails have been sent.";
$lang['%d member'] = "%d member";
$lang['%d members'] = "%d members";
$lang['%d of %d photos selected'] = '%d of %d photos selected';
$lang['%d parameter was updated.'] = "%d parameter updated.";
$lang['%d parameters were updated.'] = "%d parameters updated.";
$lang['%d photo was deleted'] = "%d photo deleted";
$lang['%d photos uploaded'] = '%d photos uploaded';
$lang['%d photos were deleted'] = "%d photos deleted";
$lang['%d physical'] = " %d physical";
$lang['%d physical'] = " %d physical";
$lang['%d tag'] = "%d tag";
$lang['%d tags'] = "%d tags";
$lang['%d user comment rejected'] = "%d user comment rejected";
$lang['%d user comment validated'] = "%d user comment validated";
$lang['%d user comments rejected'] = "%d user comments rejected";
$lang['%d user comments validated'] = "%d user comments validated";
$lang['%d user deleted'] = "%d user deleted";
$lang['%d user was not updated.'] = "%d user not updated.";
$lang['%d user was updated.'] = "%d user updated.";
$lang['%d user'] = "%d user";
$lang['%d users deleted'] = "%d users deleted";
$lang['%d users were not updated.'] = "%d users not updated.";
$lang['%d users were updated.'] = "%d users updated.";
$lang['%d users'] = "%d users";
$lang['%d waiting for validation'] = "%d waiting for validation";
$lang['%s has been successfully upgraded.'] = "%s has been successfully upgraded.";
$lang['%s must be to set to false in your local/config/config.inc.php file'] = "%s must be set to false in your local/config/config.inc.php file";
$lang['%s value is not correct file because exif are not supported'] = "%s value is incorrect because exif are not supported";
$lang['+ Add an upload box'] = '+ Add an upload box';
$lang[', click on'] = ", click on";
$lang['A local listing.xml file has been found for'] = "A local listing.xml file has been found for";
$lang['A new version of Piwigo is available.'] = "A new version of Piwigo is available.";
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = "a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory \"thumbnail\" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :";
$lang['Access type'] = "Access type";
$lang['ACCESS_0'] = "Free access";
$lang['ACCESS_1'] = "Access to all";
$lang['ACCESS_2'] = "Access to registered users";
$lang['ACCESS_3'] = "Access to administrators";
$lang['ACCESS_4'] = "Access to webmasters";
$lang['ACCESS_5'] = "No access";
$lang['Action'] = 'Action';
$lang['Actions'] = "Actions";
$lang['Activate field "%s"'] = 'Activate field "%s"';
$lang['Activate icon "%s"'] = 'Activate icon "%s"';
$lang['Activate Navigation Bar'] = 'Activate navigation bar';
$lang['Activate Navigation Thumbnails'] = 'Activate navigation thumbnails';
$lang['Activate'] = "Activate";
$lang['Activate icon "new" next to albums and pictures'] = 'Activate icon "new" next to albums and pictures';
$lang['Active Languages'] = 'Active Languages';
$lang['Active Plugins'] = 'Active Plugins';
$lang['Active Themes'] = 'Active Themes';
$lang['Add a criteria'] = 'Add a criteria';
$lang['Add a filter'] = 'Add a filter';
$lang['Add a tag'] = "Add a tag";
$lang['Add a user'] = "Add a user";
$lang['Add a virtual album'] = "Add a virtual album";
$lang['Add another set of photos'] = 'Add another set of photos';
$lang['Add detailed content'] = "Add some detailed content";
$lang['Add group'] = "Add group";
$lang['Add New Language'] = 'Add New Language';
$lang['add new photos to caddie'] = "add new photos to caddie";
$lang['Add New Theme'] = "Add a new theme";
$lang['Add Photos'] = 'Add Photos';
$lang['add tags'] = "add tags";
$lang['Add write access to the "%s" directory'] = 'Add write access to the "%s" directory';
$lang['Add'] = "Add";
$lang['Add/delete a permalink'] = "Add/delete a permalink";
$lang['added'] = "added";
$lang['Administration Home'] = 'Administration Home';
$lang['Advanced features'] = "Advanced features";
$lang['Album "%s" has been added'] = 'Album "%s" has been added';
$lang['Album "%s" now contains %d photos'] = 'Album "%s" now contains %d photos';
$lang['Album photos associated to the following albums: %s'] = "Album photos associated to the following albums: %s";
$lang['Album list management'] = "Album list management";
$lang['Album manual order was saved'] = "Album manual order was saved";
$lang['Album name'] = 'Album name';
$lang['Album updated successfully'] = "Album updated successfully";
$lang['albums added in the database'] = "albums added in the database";
$lang['Albums authorized thanks to group associations'] = "Albums authorized thanks to group associations";
$lang['Albums automatically sorted'] = 'Albums automatically sorted';
$lang['albums deleted in the database'] = "albums deleted in the database";
$lang['All %d photos are selected'] = 'All %d photos are selected';
$lang['All optimizations have been successfully completed.'] = "All optimizations have been successfully completed.";
$lang['all'] = "all";
$lang['Allow rating'] = "Allow rating";
$lang['Allow user customization'] = 'Allow user customization';
$lang['Allow user registration'] = "Allow user registration";
$lang['Allow users to delete their own comments'] = "Allow users to delete their own comments";
$lang['Allow users to edit their own comments'] = "Allow users to edit their own comments";
$lang['an error happened'] = "an error occurred";
$lang['An error occured during extraction (%s).'] = "An error occured during the files (%s) extraction.";
$lang['An information email was sent to group "%s"'] = "Information email sent to group \"%s\"";
$lang['and'] = "and";
$lang['Anomaly'] = "Anomaly";
$lang['Anyway only webmasters can see this tab and never administrators.'] = "Anyway only webmasters can see this tab, no administrators.";
$lang['Apply action'] = 'Apply action';
$lang['Apply selected corrections'] = "Apply selected corrections";
$lang['Apply to sub-albums'] = "Apply to sub-albums";
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = "Are you sure you want to install this upgrade? You must verify if this version does not need prior uninstallation.";
$lang['Are you sure you want to delete this plugin?'] = "Are you sure you want to delete this plugin?";
$lang['Are you sure you want to install this plugin?'] = "Are you sure you want to install this plugin?";
$lang['Associate to album'] = "Associate to album";
$lang['associate to group'] = "associate to group";
$lang['Associated'] = "Associated";
$lang['Authorize users to add comments on selected albums'] = "Authorize users to add comments on selected albums";
$lang['Authorized'] = "Authorized";
$lang['Automatic correction'] = "Automatic correction";
$lang['automatic order'] = 'automatic order';
$lang['Available only with HTML format'] = "Available only with HTML format";
$lang['Average rate'] = "Average rate";
$lang['average time'] = "average time";
$lang['Batch management'] = "Batch management";
$lang['Batch Manager'] = 'Batch Manager';
$lang['between'] = "between";
$lang['Bound Theme'] = 'Bound Theme';
$lang['By %s'] = 'By %s';
$lang['By rank'] = 'By rank';
$lang['Caddie management'] = "Caddie management";
$lang['Caddie'] = "Caddie";
$lang['Cannot delete the old permalink !'] = "The old permalink cannot be deleted!";
$lang['Can\'t connect to server.'] = "Connection to server impossible.";
$lang['Can\'t create temporary file.'] = "Temporary file cannot be created.";
$lang['Can\'t download archive.'] = "Archive cannot be downloaded.";
$lang['Can\'t read or extract archive.'] = "Archive cannot be read or extracted.";
$lang['Change Admin Colors'] = 'Change administration colors';
$lang['Check all'] = "Check all";
$lang['Check automatic corrections'] = "Check automatic corrections";
$lang['Check for updates'] = "Check for updates";
$lang['Check for upgrade failed for unknown reasons.'] = "Check for upgrade failed for unknown reasons.";
$lang['Check for upgrade'] = "Check for upgrade";
$lang['Check integrity'] = "Integrity check";
$lang['Choose an action'] = 'Choose an action';
$lang['Choose an option'] = "Choose an option";
$lang['Classic display'] = "Classic display";
$lang['clean'] = "clean up";
$lang['Comments for all'] = "Comments for all";
$lang['Comments'] = "Comments";
$lang['Complementary mail content'] = "Complementary mail content";
$lang['Complementary mail content'] = "Complementary mail content";
$lang['Configuration'] = "Configuration";
$lang['confirm'] = "confirm";
$lang['Continue processing treatment'] = "Continue ongoing treatment";
$lang['Correction applied with error'] = "Correction applied with error";
$lang['Correction applied with success'] = "Correction successfully applied";
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = "Corrected  anomaly will no longer be ignored";
$lang['Correction'] = "Correction";
$lang['create a new album'] = 'create a new album';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = "Create a new site : (give its URL to create_listing_file.php)";
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Create the "%s" directory at the root of your Piwigo installation';
$lang['Create this site'] = "Create this site";
$lang['created'] = "created";
$lang['Current name'] = "Current name";
$lang['Database synchronization with files'] = "Database synchronization with files";
$lang['Database'] = "Database";
$lang['Date'] = "Date";
$lang['Day'] = "Day";
$lang['Deactivate'] = "Deactivate";
$lang['Deactivate all'] = "Deactivate all";
$lang['Default display'] = "Default display";
$lang['Default photos order'] = "Default photos order";
$lang['Default user cannot be deleted'] = "Default user cannot be deleted";
$lang['Default user does not exist'] = "The default user does not exist";
$lang['default values'] = "default values";
$lang['default'] = "default";
$lang['delete album'] = "delete album";
$lang['Delete orphan tags'] = 'Delete orphan tags';
$lang['delete photo'] = 'delete photo';
$lang['Delete Representant'] = "Delete album thumbnail";
$lang['Delete selected photos'] = "Delete selected photos";
$lang['Delete selected tags'] = "Delete selected tags";
$lang['Delete selected users'] = "Delete selected users";
$lang['Delete this language'] = 'Delete this language';
$lang['delete this site and all its attached elements'] = "delete this site and all the related information";
$lang['Delete this theme'] = 'Delete this theme';
$lang['Delete'] = "Delete";
$lang['delete'] = "delete";
$lang['Deleted on'] = "Deleted on";
$lang['deleted'] = "deleted";
$lang['Deletions'] = "Deletions";
$lang['Deny selected groups'] = "Deny selected groups";
$lang['Deny selected users'] = "Deny selected users";
$lang['Description'] = "Description";
$lang['Detailed informations'] = "Detailed informations";
$lang['directories + files'] = "directories + files";
$lang['Directory does not exist'] = 'Directory does not exist';
$lang['Directory'] = "Directory";
$lang['Discover album:'] = "Discover album:";
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = "display maximum information (added albums and photos, deleted albums and photos)";
$lang['Display options'] = "Display options";
$lang['Dissociate from album'] = "Dissociate from album";
$lang['dissociate from group'] = "dissociate from group";
$lang['Dissociated'] = "Dissociated";
$lang['Documentation'] = "Documentation";
$lang['Does not represent'] = "Is not thumbnail for";
$lang['Download'] = 'Download';
$lang['Download,'] = 'Download,';
$lang['Downloads'] = "Downloads";
$lang['Drag to re-order'] = "Click-and-drag to re-order";
$lang['Drop into album'] = 'Select an album';
$lang['duplicates'] = 'duplicates';
$lang['Edit album permissions'] = "Edit album permissions";
$lang['edit album permissions'] = "edit album permissions";
$lang['Edit album'] = "Edit album";
$lang['edit album'] = "edit album";
$lang['Edit photo information'] = "Edit photo information";
$lang['Edit ranks'] = "Edit ranks";
$lang['Edit selected tags'] = "Edit selected tags";
$lang['Edit tags'] = "Edit tags";
$lang['Element type'] = "Element type";
$lang['Element'] = "Element";
$lang['photos informations synchronized with files metadata'] = "photos informations synchronized with files metadata";
$lang['Email administrators when a comment is deleted'] = "Email administrators when a comment is deleted";
$lang['Email administrators when a comment is modified'] = "Email administrators when a comment is modified";
$lang['Email admins when a comment requires validation'] = "Email admins when a comment requires validation";
$lang['Email admins when a new user registers'] = "Email admins when a new user registers";
$lang['Email admins when a valid comment is entered'] = "Email admins when a valid comment is entered";
$lang['email'] = "Email";
$lang['Environment'] = "Environment";
$lang['Error list'] = "List of errors";
$lang['Error on file "%s" : %s'] = 'Error on file "%s" : %s';
$lang['Error when sending email to %s [%s].'] = "Error when sending email to %s [%s].";
$lang['Errors caption'] = "Errors legends";
$lang['errors during synchronization'] = "errors during synchronization";
$lang['even already synchronized photos'] = "even already synchronized photos";
$lang['Everybody'] = 'Everybody';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = "Execution time exceeded, the treatment must continue [Estimated time: %d seconds].";
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = "Execution time is out, treatment must be continue [Estimated time: %d second].";
$lang['Exif extension not available, admin should disable exif use'] = 'Exif extension not available, admin should disable exif use';
$lang['existing album'] = 'existing album';
$lang['Extend for templates'] = "Extend templates";
$lang['Failed to write file to disk'] = 'Failed to write file to disk';
$lang['file create_listing_file.php on remote site was not found'] = "file create_listing_file.php not found on the remote site";
$lang['File upload stopped by extension'] = 'File upload stopped by extension';
$lang['File'] = "File";
$lang['File/directory read error'] = "File/directory read error";
$lang['Filesize'] = "Filesize";
$lang['Find a new representant by random'] = "Find a new random album thumbnail";
$lang['first photo added on %s'] = "first photo added on %s";
$lang['for the file format'] = "for the file format";
$lang['for this file format'] = "for this file format";
$lang['Forbid this language to users'] = 'Forbid this language to users';
$lang['Forbid this theme to users'] = "Forbid this theme to users";
$lang['Forbidden'] = "Forbidden";
$lang['Form'] = "Form";
$lang['FTP + Synchronization'] = 'FTP + Synchronization';
$lang['Gallery title'] = "Gallery title";
$lang['GD library is missing'] = "GD library is missing";
$lang['GD version'] = "GD version";
$lang['General statistics'] = "General statistics";
$lang['generate file listing.xml on remote site'] = "generate file listing.xml on the remote site";
$lang['generate listing'] = "generate listing";
$lang['generated in'] = "generated in";
$lang['Get Support on Piwigo Forum'] = 'Get support on Piwigo forum';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation';
$lang['global mode'] = "global mode";
$lang['Go to %s or %s for more informations'] = "Go to %s or %s for more informations";
$lang['Go to'] = "Go to";
$lang['Grant selected groups'] = "Grant selected groups";
$lang['Grant selected users'] = "Grant selected users";
$lang['group "%s" added'] = "group \"%s\" added";
$lang['group "%s" deleted'] = "group \"%s\" deleted";
$lang['group "%s" updated'] = "group \"%s\" updated";
$lang['Group management'] = "Groups management";
$lang['Group name'] = "Group name";
$lang['group'] = "group";
$lang['Group'] = "Group";
$lang['Groups'] = "Groups";
$lang['Guest cannot be deleted'] = "Guest cannot be deleted";
$lang['Guest Settings'] = 'Guest settings';
$lang['guest'] = "guest";
$lang['Guests'] = "Guests";
$lang['height must be a number superior to'] = "height must be a number greater than";
$lang['Hello'] = "Hello";
$lang['Hello,'] = "Hello,";
$lang['Help Me'] = 'Help Me';
$lang['Hide'] = "Hide";
$lang['High definition enabled'] = "High definition enabled";
$lang['High definition'] = "High definition";
$lang['High filesize'] = "High resolution filesize";
$lang['high'] = "high";
$lang['History'] = "History";
$lang['Hit'] = "Hit";
$lang['Hour'] = "Hour";
$lang['Hoverbox display'] = "Hoverbox display";
$lang['If you encounter problems or have any question, please send a message to'] = "If you encounter problems or have any question, please send a message to";
$lang['Ignore selected anomalies'] = "Ignore selected anomalies";
$lang['Image id'] = "Image id";
$lang['Image Quality'] = 'Image quality';
$lang['Images manual order was saved'] = "Images manual order saved";
$lang['Impossible automatic correction'] = "Automatic correction impossible";
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'This theme could not be activated, as the parent theme is missing: %s';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Impossible to deactivate this language, first set another language as default.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Impossible to deactivate this language, you need at least one language.';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Impossible to deactivate this theme, you need at least one theme.';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'This theme cannot be deleted, because other themes depends on it: %s';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting';
$lang['Inactive Languages'] = 'Inactive Languages';
$lang['Inactive Plugins'] = 'Inactive Plugins';
$lang['Inactive Themes'] = 'Inactive themes';
$lang['include child albums'] = 'include child albums';
$lang['Include display of recent photos grouped by dates'] = "Include display of recent photos grouped by dates";
$lang['Information data registered in database'] = "Information data registered in database";
$lang['Informations'] = "Information";
$lang['Install on your computer,'] = 'Install on your computer,';
$lang['Install'] = "Install";
$lang['Installed Languages'] = 'Installed Languages';
$lang['Installed Themes'] = "Installed Themes";
$lang['Instructions to use Piwigo'] = "Instructions to use Piwigo";
$lang['Invert'] = 'Invert';
$lang['IP'] = "IP";
$lang['jump to album'] = "jump to album";
$lang['jump to photo'] = "jump to photo";
$lang['Keep high definition'] = 'Keep high definition';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = "Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will be sent emails when a new release is available (sometimes including a security bug fix, it is important to know and upgrade) and when major events happen to the project. Only a few emails a year.";
$lang['Language has been successfully installed'] = 'Language has been successfully installed';
$lang['Languages'] = 'Languages';
$lang['Last hit'] = "Last hit";
$lang['last import'] = 'last import';
$lang['Last revisions'] = "Last revisions";
$lang['Last send'] = "Last sent";
$lang['leave'] = "leave";
$lang['Level 0'] = "---";
$lang['Level 1'] = "Contacts";
$lang['Level 2'] = "Friends";
$lang['Level 4'] = "Family";
$lang['Level 8'] = "Admins";
$lang['Link all album photos to a new album'] = "Link all album photos to a new album";
$lang['Link all album photos to some existing albums'] = "Link all album photos to some existing albums";
$lang['Linked albums'] = "Linked albums";
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = "listing.xml file not found on the remote site. This file is generated with the \"generate listing\" command in the Site manager";
$lang['listing.xml file was not found'] = "listing.xml file not found";
$lang['Local'] = "Local";
$lang['Lock albums'] = "Lock albums";
$lang['Lock gallery'] = "Lock gallery";
$lang['Lock'] = "Lock";
$lang['Locked'] = "Locked";
$lang['Mail address is obligatory for all users'] = "Mail address is mandatory for all users";
$lang['Mail content'] = "Mail content";
$lang['Mail sent to %s [%s].'] = "Mail sent to %s [%s].";
$lang['Main "guest" user does not exist'] = "The main \"guest\" user does not exist";
$lang['Main "guest" user status is incorrect'] = "The main \"guest\" user status is incorrect";
$lang['Main "webmaster" user does not exist'] = "The main \"webmaster\" user does not exist";
$lang['Main "webmaster" user status is incorrect'] = "The main \"webmaster\" user status is incorrect";
$lang['Main Page'] = 'Main page';
$lang['Main'] = "Main";
$lang['Maintenance'] = "Maintenance";
$lang['Make this language available to users'] = 'Make this language available to users';
$lang['Make this theme available to users'] = 'Make this theme available to users';
$lang['manage album photos'] = "manage album photos";
$lang['Manage authorizations for selected albums'] = "Manage authorizations for selected albums";
$lang['Manage permissions for group "%s"'] = "Manage permissions for the group \"%s\"";
$lang['Manage permissions for user "%s"'] = "Manage permissions for the user \"%s\"";
$lang['Manage photo ranks'] = "Manage photo ranks";
$lang['manage photo ranks'] = "manage photo ranks";
$lang['manage sub-albums'] = "manage sub-albums";
$lang['Manage tags'] = "Manage tags";
$lang['Manage this set of %d photos'] = 'Manage this set of %d photos';
$lang['Manage'] = "Manage";
$lang['Manual order'] = 'Manual order';
$lang['manual order'] = 'manual order';
$lang['max time'] = "max time";
$lang['maximum height'] = "Maximum height";
$lang['Maximum Height'] = 'Maximum height';
$lang['maximum width'] = "Maximum width";
$lang['Maximum Width'] = 'Maximum Width';
$lang['Members'] = "Members";
$lang['Menu Management'] = 'Menus';
$lang['Metadata synchronization results'] = "Metadata synchronization results";
$lang['Metadata synchronized from file'] = "Metadata synchronized from file";
$lang['min time'] = "min time";
$lang['Miniaturization parameters'] = "Miniaturization parameters";
$lang['Minimum privacy level'] = "Minimum privacy level";
$lang['Miscellaneous'] = 'Miscellaneous';
$lang['Missing a temporary folder'] = 'Missing a temporary folder';
$lang['Missing Plugins'] = 'Missing Plugins';
$lang['missing thumbnail'] = "missing thumbnail";
$lang['Modify information'] = "Modify information";
$lang['Month'] = "Month";
$lang['Move albums'] = "Move albums";
$lang['Move'] = "Move";
$lang['Name'] = "Name";
$lang['new'] = "new";
$lang['New name'] = "New name";
$lang['New parent album'] = "New parent album";
$lang['New photos added'] = "New photos added";
$lang['New photos were added'] = "New photos have been added";
$lang['New tag'] = "New tag";
$lang['No display'] = "No display";
$lang['No file was uploaded'] = 'No file was uploaded';
$lang['No mail to send.'] = "No mail to be sent.";
$lang['No missing thumbnail'] = "No missing thumbnail";
$lang['No photo can be deleted'] = "No photo can be deleted";
$lang['No photo in the current set.'] = 'No photo in the current set.';
$lang['No photo in this album'] = "No photo in this album";
$lang['No photo selected, %d photos in current set'] = 'No photo selected, %d photos in current set';
$lang['No photo selected, no action possible.'] = 'No photo selected, no action possible.';
$lang['No results'] = "No results";
$lang['No user to send notifications by mail.'] = "No user to be notified by mail.";
$lang['no write access'] = "no write access";
$lang['none'] = "none";
$lang['None'] = 'None';
$lang['nothing'] = "nothing";
$lang['Notification'] = "Notification";
$lang['Number of comments per page'] = "Number of comments per page";
$lang['Number of downloads'] = "Number of downloads";
$lang['number of miniaturized photos'] = "number of thumbnails created";
$lang['Number of rates'] = "Number of rates";
$lang['Number of thumbnails to create'] = "Number of thumbnails to create";
$lang['on the %d selected photos'] = 'on the %d selected photos';
$lang['on'] = "on";
$lang['only directories'] = "directories only";
$lang['only perform a simulation (no change in database will be made)'] = "only perform a simulation (nothing will be changed in the database)";
$lang['Only private albums are listed'] = "Only private albums are listed";
$lang['Operating system'] = "Operating system";
$lang['Operation in progress'] = 'Treatment in progress.';
$lang['Optimizations have been completed with some errors.'] = "Optimizations have been completed with some errors.";
$lang['Optional URL keyword'] = "Optional URL keyword";
$lang['Options'] = "Options";
$lang['Options'] = "Options";
$lang['Order of menubar items has been updated successfully.'] = 'Order of menubar items has been updated successfully.';
$lang['Original templates'] = "Original templates";
$lang['Orphan tags deleted'] = 'Orphan tags deleted';
$lang['Other plugins'] = "Other plugins available";
$lang['Other private albums'] = "Other private albums";
$lang['other'] = "other";
$lang['Overall'] = "Overview";
$lang['overrides existing values with empty ones'] = "overrides existing values with empty ones";
$lang['Page banner'] = "Page banner";
$lang['Page end'] = 'Page end';
$lang['Pages seen'] = "Pages seen";
$lang['Parameter'] = "Settings";
$lang['Parameters'] = "Parameters";
$lang['Parent album'] = "Parent album";
$lang['Password confirmation error.'] = "Password confirmation error.";
$lang['Password confirmation is missing. Please confirm the chosen password.'] = "Password confirmation is missing. Please confirm the chosen password.";
$lang['Password is missing. Please enter the password.'] = "Password is missing. Please enter the password.";
$lang['Path'] = "Path";
$lang['Pending Comments'] = 'Pending Comments';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = "Permalink %s has previously been used by album %s. Delete it from the permalinks history first";
$lang['Permalink %s is already used by album %s'] = "Permalink %s is already used by album %s";
$lang['Permalink history'] = "Permalinks history";
$lang['Permalink'] = "Permalink";
$lang['Permalinks'] = "Permalinks";
$lang['Permission denied'] = "Permission denied";
$lang['Permission granted thanks to a group'] = "Permission granted thanks to a group";
$lang['Permission granted'] = "Permission granted";
$lang['Permissions'] = "Permissions";
$lang['Photo Page'] = 'Photo page';
$lang['Photo Properties'] = 'Photo properties';
$lang['photos added in the database'] = "photos added in the database";
$lang['photos candidates for metadata synchronization'] = "photos candidates for metadata synchronization";
$lang['photos deleted from the database'] = "photos deleted from the database";
$lang['photos per page'] = "photos per page";
$lang['photos updated in the database'] = "photos updated in the database";
$lang['Photos'] = "Photos";
$lang['Photo informations updated'] = "Photo informations updated";
$lang['Photo unreachable or no support'] = "Photo unreachable or unsupported format";
$lang['photos without thumbnail (jpeg and png only)'] = "photos without thumbnail (jpeg and png only)";
$lang['Piwigo Administration'] = "Piwigo Administration";
$lang['Piwigo Announcements Newsletter'] = "Piwigo Announcement Newsletter";
$lang['Piwigo configuration'] = "Piwigo configuration";
$lang['Piwigo Uploader'] = 'Piwigo Uploader';
$lang['Piwigo version differs on the remote site'] = "Piwigo version differs on the remote site";
$lang['Piwigo version'] = "Piwigo version";
$lang['pixels'] = 'pixels';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = "Please check \"plugins\" folder and sub-folders permissions (CHMOD).";
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.';
$lang['Plugin has been successfully copied'] = "The plugin has been successfully copied";
$lang['Plugin list'] = "Plugins list";
$lang['Plugins which need upgrade'] = "Plugins to be upgraded";
$lang['Plugins'] = "Plugins";
$lang['Position'] = "Position";
$lang['predefined filter'] = 'predefined filter';
$lang['Preferences'] = "Preferences";
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = "The time to prepare the list of users who will be sent mail is limited. Others users are not listed.";
$lang['Privacy level set to "%s"'] = 'Privacy level set to "%s"';
$lang['Privacy level'] = "Privacy level";
$lang['Private'] = "Private";
$lang['private'] = "private";
$lang['Properties'] = "Properties";
$lang['Public / Private'] = "Public / Private";
$lang['Public'] = "Public";
$lang['public'] = "public";
$lang['Purge compiled templates'] = "Purge compiled templates";
$lang['Purge history detail'] = "Purge history details";
$lang['Purge history summary'] = "Purge history summary";
$lang['Purge never used notification feeds'] = "Purge never used notification feeds";
$lang['Purge search history'] = "Purge search history";
$lang['Purge sessions'] = "Purge sessions";
$lang['Quick Local Synchronization'] = "Quick Local Synchronization";
$lang['Random photo'] = "Random photo";
$lang['randomly represented'] = "random album thumbnail";
$lang['ranks'] = "ranks";
$lang['Rate'] = "Rate";
$lang['Rate date'] = "Rate date";
$lang['Rating by guests'] = "Rating by guests";
$lang['Rating'] = "Rating";
$lang['read local listing.xml and update'] = "read local listing.xml and update";
$lang['Read Piwigo Documentation'] = 'Read Piwigo Documentation';
$lang['reduce to single existing albums'] = "reduce to single existing albums";
$lang['Refresh photo set'] = 'Refresh photo set';
$lang['Refresh'] = "Refresh";
$lang['registration date'] = "registration date";
$lang['Reinitialize check integrity'] = "Reinitialize integrity check";
$lang['Reject'] = "Reject";
$lang['Released on'] = "Released on";
$lang['Remote'] = "Remote";
$lang['Remove all filters'] = 'Remove all filters';
$lang['remove author'] = 'remove author';
$lang['remove creation date'] = 'remove creation date';
$lang['Remove from caddie'] = 'Remove from caddie';
$lang['remove remote listing.xml file'] = "remove remote listing.xml file";
$lang['remove tags'] = "remove tags";
$lang['remove this filter'] = 'remove this filter';
$lang['remove title'] = 'remove title';
$lang['Repair and optimize database'] = "Repair and optimize database";
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = "Replacement of original templates by customized templates from the template-extension subfolder";
$lang['Replacers (customized templates)'] = "Substitutes (customized templates)";
$lang['Representant'] = "Album Thumbnail";
$lang['Representation of albums'] = "Album thumbnail";
$lang['Representative'] = 'Album thumbnail';
$lang['Represents'] = 'Is thumbnail for';
$lang['Resize'] = 'Resize';
$lang['Restore'] = "Restore";
$lang['Restore default configuration. You will lose your plugin settings!'] = "Restore default configuration. You will lose your plugin settings!";
$lang['Results of miniaturization'] = "Miniaturization process results";
$lang['Save order'] = "Save order";
$lang['Save page visits by administrators'] = "Record pages visited by administrators";
$lang['Save page visits by guests'] = "Record pages visited by guests";
$lang['Save page visits by users'] = "Record pages visited by users";
$lang['Save Settings'] = 'Save Settings';
$lang['Save to permalink history'] = "Save to permalinks history";
$lang['Searching...'] = "Searching...";
$lang['Search for new images in the directories'] = "Search for new images in the directories";
$lang['Section'] = "Section";
$lang['See you soon,'] = "See you soon,";
$lang['See you soon.'] = "See you soon.";
$lang['Select at least one album'] = "Select at least one album";
$lang['Select at least one comment'] = 'Select at least one comment';
$lang['Select at least one photo'] = "Select at least one photo";
$lang['Select at least one user'] = "Select at least one user";
$lang['Select files'] = 'Select files';
$lang['Select recipients'] = "Select recipients";
$lang['Select:'] = 'Select:';
$lang['selection'] = "selection";
$lang['Selection'] = 'Selection';
$lang['Send an information email to group members'] = "Send an information email to group members";
$lang['Send mail as'] = "Send mail as";
$lang['Send mail on HTML format'] = "Send mail in HTML format";
$lang['Send mail to users'] = "Send mail to users";
$lang['Send'] = "Send";
$lang['Set as default language for unregistered and new users'] = 'Set as default language for unregistered and new users';
$lang['Set as default theme for unregistered and new users'] = "Set as default theme for unregistered and new users";
$lang['Set author'] = 'Set author';
$lang['Set creation date'] = 'Set creation date';
$lang['Set title'] = 'Set title';
$lang['set to'] = "set to";
$lang['Settings'] = 'Settings';
$lang['Show info'] = "Show info";
$lang['Show menubar'] = "Show menubar";
$lang['Simulation'] = "Simulation";
$lang['singly represented'] = 'fixed album thumbnail';
$lang['Site manager'] = "Site manager";
$lang['Specials'] = "Specials";
$lang['Start pLoader and add your photos.'] = 'Start pLoader and add your photos.';
$lang['Statistics'] = "Statistics";
$lang['Status of user "%s" updated'] = "User \"%s\" status updated";
$lang['Status'] = "Status";
$lang['status'] = "status";
$lang['Storage album'] = "Storage album";
$lang['sub-albums'] = "sub-albums";
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = "Subscribe %s to Piwigo Announcements Newsletter";
$lang['Subscribe %s'] = "Subscribe %s";
$lang['Subscribe to notification by mail'] = "Subscribe to notification by mail";
$lang['Subscribe'] = "Subscribe";
$lang['Subscribe/unsubscribe users'] = "Subscribe/unsubscribe users";
$lang['Subscribed'] = "Subscribed";
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = "Subscribers could be listed (available) only if there is new elements to notify.";
$lang['Sum of rates'] = "Sum of rates";
$lang['Summary'] = "Summary";
$lang['Support'] = "Support";
$lang['Switch to clear or dark colors for administration'] = 'Switch to clear or dark colors for administration';
$lang['synchronize files metadata with database photos informations'] = "synchronize database photos with files metadata";
$lang['synchronize files structure with database'] = "synchronize files structure with database";
$lang['synchronize metadata'] = "synchronize metadata";
$lang['Synchronize'] = "Synchronize";
$lang['synchronize'] = "synchronize";
$lang['Tag "%s" already exists'] = "Tag \"%s\" already exists";
$lang['Tag "%s" was added'] = "Tag \"%s\" has been added";
$lang['Tag selection'] = "Tags selection";
$lang['Tags'] = "Tags";
$lang['target'] = "target";
$lang['Templates configuration has been recorded.'] = "Templates configuration has been recorded.";
$lang['Templates'] = "Templates";
$lang['test this remote site'] = "test this remote site";
$lang['test'] = "test";
$lang['The %d following tags were deleted'] = "The following %d tags have been deleted";
$lang['The anomaly will be ignored until next application version'] = "The anomaly will be ignored until next application version";
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = "The file or directory cannot be accessed (either it does not exist or the access is denied)";
$lang['The following tag was deleted'] = 'The following tag was deleted';
$lang['the forum'] = "the forum";
$lang['The gallery URL is not valid.'] = "The gallery URL is not valid.";
$lang['The high definition image quality must be a number between %d and %d'] = 'The high definition image quality must be a number between %d and %d';
$lang['The high definition maximum height must be a number between %d and %d'] = 'The high definition maximum height must be a number between %d and %d';
$lang['The high definition maximum width must be a number between %d and %d'] = 'The high definition maximum width must be a number between %d and %d';
$lang['The name of a group must not contain " or \' or be empty.'] = "The name of a group must not contain \" or ' or be empty.";
$lang['The name of an album must not be empty'] = "The name of an album must not be empty";
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = "The name of directories and files must comprise only letters, numbers, \"-\", \"_\" or \".\"";
$lang['The number of comments a page must be between 5 and 50 included.'] = "The number of comments on a page must be between 5 and 50 included.";
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = "The permalink name must be composed of a-z, A-Z, 0-9, \"-\", \"_\" or \"/\". It must not be numeric or begin with a number followed by \"-\"";
$lang['The thumbnail image quality must be a number between %d and %d'] = 'The thumbnail image quality must be a number between %d and %d';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'The thumbnail maximum height must be a number between %d and %d';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'The thumbnail maximum width must be a number between %d and %d';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB';
$lang['The uploaded file was only partially uploaded'] = 'The uploaded file was only partially uploaded';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'The uploaded files exceed the post_max_size directive in php.ini: %sB';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = "The version of %s [%s] installed is not compatible with the version required [%s]";
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = "The webmaster has subscribed you to be notified by mail.";
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = "The webmaster has unsubscribed you from receiving notifications by mail.";
$lang['The websize image quality must be a number between %d and %d'] = 'The websize image quality must be a number between %d and %d';
$lang['The websize maximum height must be a number between %d and %d'] = 'The websize maximum height must be a number between %d and %d';
$lang['The websize maximum width must be a number between %d and %d'] = 'The websize maximum width must be a number between %d and %d';
$lang['The whole page'] = 'The whole page';
$lang['The whole set'] = 'The whole set';
$lang['the wiki'] = "the wiki";
$lang['Theme has been successfully installed'] = 'Theme has been successfully installed';
$lang['Themes'] = "Themes";
$lang['There is no available subscribers to mail.'] = "There is no subscribers to be notified by mail.";
$lang['There is no other language available.'] = 'There is no other language available.';
$lang['There is no other plugin available.'] = 'There is no other plugin available.';
$lang['There is no other theme available.'] = 'There is no other theme available.';
$lang['This name is already used by another group.'] = "This name is already used by another group.";
$lang['This site already exists'] = "This site already exists";
$lang['This theme was not designed to be directly activated'] = 'This theme was not designed to be directly activated';
$lang['Thumbnail creation'] = "Thumbnail creation";
$lang['Thumbnail'] = "Thumbnail";
$lang['Thumbnail'] = 'Thumbnail';
$lang['Time to send mail is limited. Others mails are skipped.'] = "The time to send mail is limited. Others mails have been skipped.";
$lang['Time'] = "Time";
$lang['title'] = "title";
$lang['To send ?'] = "To send?";
$lang['To subscribe'] = "To subscribe";
$lang['To unsubscribe'] = "To unsubscribe";
$lang['Toggle \'default group\' property'] = "Reverse 'default group' property";
$lang['Tools'] = "Tools";
$lang['total time'] = "total time";
$lang['Type here the author name'] = 'Type here the author name';
$lang['Type here the title'] = 'Type here the title';
$lang['Type in a search term'] = "Type in a search term";
$lang['Unable to check for upgrade.'] = "Unable to check for upgrade.";
$lang['Uncheck all'] = "Uncheck all";
$lang['Uninstall'] = "Uninstall";
$lang['Uninstalled Plugins'] = 'Uninstalled Plugins';
$lang['unit mode'] = "single mode";
$lang['Unknown upload error'] = 'Unknown upload error';
$lang['unknown'] = 'unknown';
$lang['Unlocked'] = "Unlocked";
$lang['unset'] = "unset";
$lang['Unsubscribe from notification by mail'] = "Unsubscribe from notification by mail";
$lang['Unsubscribed'] = "Unsubscribed";
$lang['Update albums informations'] = "Update albums information";
$lang['Update photos information'] = "Update photos information";
$lang['update the database from files'] = "update the database with files";
$lang['Upload Photos'] = 'Upload Photos';
$lang['Upload'] = "Upload";
$lang['Uploaded Photos'] = 'Uploaded Photos';
$lang['Use the default photo sort order (defined in the configuration file)'] = "Use the default photo sort order (defined in the configuration file)";
$lang['Used metadata'] = "Metadata used";
$lang['user "%s" added'] = "user \"%s\" added";
$lang['User "%s" created with "%s" like password'] = "User \"%s\" created with \"%s\" as password";
$lang['User %s [%s] added.'] = "User %s [%s] added.";
$lang['User %s [%s] was added to the subscription list.'] = "User %s [%s] added to the subscription list.";
$lang['User %s [%s] was not added to the subscription list.'] = "User %s [%s] not added to the subscription list.";
$lang['User %s [%s] was not removed from the subscription list.'] = "User %s [%s] not removed from the subscription list.";
$lang['User %s [%s] was removed from the subscription list.'] = "User %s [%s] removed from the subscription list.";
$lang['User comments validation'] = "User comments validation";
$lang['User list'] = "Users list";
$lang['User status'] = "User status";
$lang['User'] = "User";
$lang['Users'] = "Users";
$lang['user_status_admin'] = "Administrator";
$lang['user_status_generic'] = "Generic";
$lang['user_status_guest'] = "Guest";
$lang['user_status_normal'] = "User";
$lang['user_status_webmaster'] = "Webmaster";
$lang['Validate'] = "Validate";
$lang['Validation'] = "Validation";
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = "Versions of create_listing_file.php on the remote site and Piwigo must be the same";
$lang['Version'] = "Version";
$lang['Virtual album added'] = "Virtual album added";
$lang['Virtual album deleted'] = "Virtual album deleted";
$lang['Virtual album name'] = "Virtual album name";
$lang['Virtual album'] = "Virtual album";
$lang['Virtual albums to move'] = "Virtual albums to move";
$lang['Virtual Links'] = 'Virtual Links';
$lang['Visit Gallery'] = 'Visit the gallery';
$lang['Visit Piwigo project website'] = 'Visit Piwigo project website';
$lang['Visit plugin site'] = 'Visit plugin site';
$lang['Waiting'] = "Pending";
$lang['Warning: subscribing or unsubscribing will send mails to users'] = "Warning: subscribing or unsubscribing will send mails to users";
$lang['Web size photo'] = 'Web size photo';
$lang['Webmaster cannot be deleted'] = "Webmaster cannot be deleted";
$lang['Webmaster status is required.'] = 'Webmaster status is required.';
$lang['Week starts on'] = 'Week starts on';
$lang['Who can see these photos?'] = 'Who can see these photos?';
$lang['Who can see this photo?'] = 'Who can see this photo?';
$lang['width must be a number superior to'] = "width must be a number greater than";
$lang['With blank value, gallery title will be used'] = "If blank, the gallery title will be used";
$lang['with no album'] = 'with no album';
$lang['with no tag'] = 'with no tag';
$lang['with no virtual album'] = 'with no virtual album';
$lang['wrong filename'] = "wrong filename";
$lang['Year'] = "Year";
$lang['You are running on development sources, no check possible.'] = "You are running on development sources, no check possible.";
$lang['You are running the latest version of Piwigo.'] = "You are running Piwigo latest version.";
$lang['You cannot delete your account'] = "You cannot delete your account";
$lang['You cannot move an album in its own sub album'] = "You cannot move an album in its own sub album";
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = 'You can\'t define a default photo order because you have a custom setting in your local configuration.';
$lang['You have %d orphan tags: %s.'] = 'You have %d orphan tags: %s.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !';
$lang['You have subscribed to receiving notifications by mail.'] = "You have subscribed to receive notifications by mail.";
$lang['You have unsubscribed from receiving notifications by mail.'] = "You have unsubscribed from being notified by mail.";
$lang['You might go to plugin list to install and activate it.'] = "Go to the plugins list to install and activate it.";
$lang['You need to confirm deletion'] = "You must confirm deletion";
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = "You should upgrade your system to take full advantage of the application, otherwise the application could work improperly, or not at all";
$lang['Your configuration settings are saved'] = 'Your configuration settings are saved';
$lang['[%s] Visit album %s'] = "[%s] Visit album %s";
$lang['[NBM] Problems or questions'] = "[NBM] Problems or questions";
$lang['[Simulation]'] = "[Simulation]";
$lang['Themes which need upgrade'] = 'Themes which need upgrade';
$lang['Languages which need upgrade'] = 'Languages which need upgrade';
$lang['All themes are up to date.'] = 'All themes are up to date.';
$lang['All plugins are up to date.'] = 'All plugins are up to date.';
$lang['All languages are up to date.'] = 'All languages are up to date.';
$lang['Visit theme site'] = 'Visit theme site';
$lang['Visit language site'] = 'Visit language site';
$lang['New Version'] = 'New Version';
$lang['Obsolete Plugins'] = 'Obsolete Plugins';
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'WARNING! This plugin does not seem to be compatible with this version of Piwigo.';
$lang['Do you want to activate anyway?'] = 'Do you want to activate anyway?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'THIS PLUGIN IS NOW PART OF PIWIGO CORE! UNINSTALL IT NOW!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.';
$lang['display'] = 'display';
$lang['Regenerate Thumbnails'] = 'Regenerate Thumbnails';
$lang['Regenerate Websize Photos'] = 'Regenerate Websize Photos';
$lang['Thumbnails generation in progress...'] = 'Thumbnails generation in progress...';
$lang['Photos generation in progress...'] = 'Photos generation in progress...';
$lang['%s thumbnails have been regenerated'] = '%s thumbnails have been regenerated';
$lang['%s thumbnails can not be regenerated'] = '%s thumbnails can not be regenerated';
$lang['%s photos have been regenerated'] = '%s photos have been regenerated';
$lang['%s photos can not be regenerated'] = '%s photos can not be regenerated';

$lang['Updates'] = 'Updates';
$lang['Update in progress... Please wait.'] = 'Update in progress... Please wait.';
$lang['Ignore this update'] = 'Ignore this update';
$lang['Reset ignored updates'] = 'Reset ignored updates';
$lang['Update All'] = 'Update All';
$lang['ERROR'] = 'ERROR';
$lang['Update Complete'] = 'Update Complete';
$lang['Piwigo Update'] = 'Piwigo Update';
$lang['Extensions Update'] = 'Extensions Update';
$lang['All extensions are up to date.'] = 'All extensions are up to date.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Following plugins may not be compatible with the new version of Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = 'Following themes may not be compatible with the new version of Piwigo:';
$lang['I decide to update anyway'] = 'I decide to update anyway';
$lang['Update to Piwigo %s'] = 'Update to Piwigo %s';
$lang['Two updates are available'] = 'Two updates are available';
$lang['This is a minor update, with only bug corrections.'] = 'This is a minor update, with only bug corrections.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'This is a major update, with <a href="%s">new exciting features</a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Some themes and plugins may be not available yet.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).';
$lang['Save Template Directory'] = 'Save template directory';
$lang['Dump Database'] = 'Dump Database';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Include history data (Warning: server memory limit may be exceeded)';
$lang['Unable to write new local directory.'] = 'Unable to write new local directory.';
$lang['Unable to send template directory.'] = 'Unable to send template directory.';
$lang['Unable to dump database.'] = 'Unable to dump database.';
$lang['Some upgrades are available for extensions.'] = 'Some upgrades are available for extensions.';
$lang['Please wait...'] = 'Please wait...';
$lang['Ignore All'] = 'Ignore All';
$lang['Crop'] = 'Crop';
$lang['Width'] = 'Width';
$lang['Height'] = 'Height';
$lang['Follow Orientation'] = 'Follow Orientation';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.';
$lang['Graphics Library'] = 'Graphics Library';
$lang['... or '] = '... or ';
$lang['Create'] = 'Create';
$lang['Start Upload'] = 'Start Upload';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.';
$lang['Maximum file size: %sB.'] = 'Maximum file size: %sB.';
$lang['Allowed file types: %s.'] = 'Allowed file types: %s.';
$lang['Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).'] = 'Approximate maximum resolution: %dM pixels (that\'s %dx%d pixels).';
$lang['Manage Permissions'] = 'Manage Permissions';
$lang['Photo %s of %s'] = 'Photo %s of %s';
$lang['show details'] = 'show details';
$lang['hide details'] = 'hide details';
$lang['Merge tags'] = 'Merge tags';
$lang['Select the destination tag'] = 'Select the destination tag';
$lang['(this tag will be deleted)'] = '(this tag will be deleted)';
$lang['Confirm merge'] = 'Confirm merge';
$lang['Merge selected tags'] = 'Merge selected tags';
$lang['No destination tag selected'] = 'No destination tag selected';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Tags <em>%s</em> merged into tag <em>%s</em>';
$lang['Select at least two tags for merging'] = 'Select at least two tags for merging';
$lang['Learn more'] = 'Learn more';
$lang['Select an album'] = 'Select an album';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'By default, Piwigo will create a new websize from the HD (high definition) version of your photo.';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.';

$lang['An error has occured during upgrade.'] = 'An error has occured during upgrade.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo cannot retrieve upgrade file from server';
?>
